@@ -1,4 +1,5 @@
 import typing as T
+import re
 from uuid import UUID
 from datetime import datetime, timedelta
 from zoneinfo import ZoneInfo
@@ -67,6 +68,8 @@ def model_dict_to_str(
                 continue
 
         variable_name = f"{field_name}{random_str(10)}"
+        # if enum, turn to str cast instead
+        type_cast_str = re.sub(r"default::\w+", "std::str", type_cast_str)
         field_str = f"{field_name} := <{type_cast_str}>${variable_name}"
         if type_cast_str.endswith("::str") and (
             isinstance(val, dict) or isinstance(val, list)
