@@ -205,6 +205,12 @@ class Resolver(BaseModel, T.Generic[NodeType]):
     def _add_variables(
         self, /, variables: T.Optional[T.Dict[str, T.Any]] = None
     ) -> None:
+        # turn enums into strs
+        if variables:
+            variables = {
+                k: v if not isinstance(v, Enum) else v.value
+                for k, v in variables.items()
+            }
         if variables is not None:
             self.validate_against_query_variables(variables)
             self._query_variables = {**self._query_variables, **variables}
